pub enum QueryRequest {
Show 24 variants
InterfaceStats,
PathTable {
max_hops: Option<u8>,
},
RateTable,
NextHop {
dest_hash: [u8; 16],
},
NextHopIfName {
dest_hash: [u8; 16],
},
LinkCount,
DropPath {
dest_hash: [u8; 16],
},
DropAllVia {
transport_hash: [u8; 16],
},
DropAnnounceQueues,
TransportIdentity,
GetBlackholed,
BlackholeIdentity {
identity_hash: [u8; 16],
duration_hours: Option<f64>,
reason: Option<String>,
},
UnblackholeIdentity {
identity_hash: [u8; 16],
},
HasPath {
dest_hash: [u8; 16],
},
HopsTo {
dest_hash: [u8; 16],
},
RecallIdentity {
dest_hash: [u8; 16],
},
LocalDestinations,
Links,
Resources,
InjectPath {
dest_hash: [u8; 16],
next_hop: [u8; 16],
hops: u8,
expires: f64,
interface_name: String,
packet_hash: [u8; 32],
},
InjectIdentity {
dest_hash: [u8; 16],
identity_hash: [u8; 16],
public_key: [u8; 64],
app_data: Option<Vec<u8>>,
hops: u8,
received_at: f64,
},
DiscoveredInterfaces {
only_available: bool,
only_transport: bool,
},
SendProbe {
dest_hash: [u8; 16],
payload_size: usize,
},
CheckProof {
packet_hash: [u8; 32],
},
}Expand description
Queries that can be sent to the driver.
Variants
InterfaceStats
Get interface statistics and transport info.
PathTable
Get path table entries, optionally filtered by max hops.
RateTable
Get rate table entries.
NextHop
Look up the next hop for a destination.
NextHopIfName
Look up the next hop interface name for a destination.
LinkCount
Get link table entry count.
DropPath
Drop a specific path.
DropAllVia
Drop all paths that route via a given transport hash.
DropAnnounceQueues
Drop all announce queues.
TransportIdentity
Get the transport identity hash.
GetBlackholed
Get all blackholed identities.
BlackholeIdentity
Add an identity to the blackhole list.
UnblackholeIdentity
Remove an identity from the blackhole list.
HasPath
Check if a path exists to a destination.
HopsTo
Get hop count to a destination.
RecallIdentity
Recall identity info for a destination.
LocalDestinations
Get locally registered destinations.
Links
Get active links.
Resources
Get active resource transfers.
InjectPath
Inject a path entry into the path table.
Fields
InjectIdentity
Inject an identity into the known destinations cache.
Fields
DiscoveredInterfaces
Get discovered interfaces.
SendProbe
Send a probe packet to a destination and return (packet_hash, hops).
CheckProof
Check if a proof was received for a probe packet.