pub enum RequestResponse {
Bytes(Vec<u8>),
Resource {
data: Vec<u8>,
metadata: Option<Vec<u8>>,
auto_compress: bool,
},
}Expand description
Response produced by an application request handler.
Variants
Bytes(Vec<u8>)
Send the response as the normal request response value.
Resource
Send the response as a resource response with optional metadata.