pub struct ReticulumSection {Show 20 fields
pub enable_transport: bool,
pub share_instance: bool,
pub instance_name: String,
pub shared_instance_port: u16,
pub instance_control_port: u16,
pub panic_on_interface_error: bool,
pub use_implicit_proof: bool,
pub network_identity: Option<String>,
pub respond_to_probes: bool,
pub enable_remote_management: bool,
pub remote_management_allowed: Vec<String>,
pub publish_blackhole: bool,
pub probe_port: Option<u16>,
pub probe_addr: Option<String>,
pub probe_protocol: Option<String>,
pub device: Option<String>,
pub discover_interfaces: bool,
pub required_discovery_value: Option<u8>,
pub prefer_shorter_path: bool,
pub max_paths_per_destination: usize,
}Expand description
The [reticulum] section.
Fields
enable_transport: boolinstance_name: Stringinstance_control_port: u16panic_on_interface_error: booluse_implicit_proof: boolnetwork_identity: Option<String>respond_to_probes: boolenable_remote_management: boolremote_management_allowed: Vec<String>publish_blackhole: boolprobe_port: Option<u16>probe_addr: Option<String>probe_protocol: Option<String>Protocol for endpoint discovery: “rnsp” (default) or “stun”.
device: Option<String>Network interface to bind outbound sockets to (e.g. “usb0”).
discover_interfaces: boolEnable interface discovery (advertise discoverable interfaces and listen for discovery announces from the network).
required_discovery_value: Option<u8>Minimum stamp value for accepting discovered interfaces.
prefer_shorter_path: boolAccept an announce with strictly fewer hops even when the random_blob is a duplicate of the existing path entry.
max_paths_per_destination: usizeMaximum number of alternative paths stored per destination. Default 1 (single path, backward-compatible).